@@ -5,6 +5,8 @@ from politylink.graphql import POLITYLINK_AUTH, POLITYLINK_URL
 from politylink.graphql.schema import *
 from politylink.graphql.schema import _UrlInput, _BillInput, _SpeechInput, _MinutesInput, _CommitteeInput, _NewsInput
 
+MAX_BATCH_SIZE = 100
+
 
 class GraphQLException(Exception):
     pass
@@ -16,7 +18,7 @@ class GraphQLClient:
     """
 
     def __init__(self, url=POLITYLINK_URL, auth=POLITYLINK_AUTH):
-        self.endpoint = HTTPEndpoint(url, {'Authorization': auth}, timeout=3)
+        self.endpoint = HTTPEndpoint(url, {'Authorization': auth}, timeout=30)
 
     def exec(self, op):
         """
@@ -42,14 +44,21 @@ class GraphQLClient:
     def bulk_merge(self, objects):
         """
         General method to bulk merge GraphQL objects
+        requests will be send in batch to avoid Payload Too Large exception
         :param objects: list of GraphQL objects
-        :return: json data
+        :return: json data of the last request
         """
 
+        ret = None
         op = Operation(Mutation)
         for obj in objects:
             op = self.build_merge_operation(obj, op)
-        return self.exec(op)
+            if len(op) >= MAX_BATCH_SIZE:
+                ret = self.exec(op)
+                op = Operation(Mutation)
+        if len(op):
+            ret = self.exec(op)
+        return ret
 
     def link(self, from_id, to_id):
         """
@@ -65,15 +74,22 @@ class GraphQLClient:
     def bulk_link(self, from_ids, to_ids):
         """
         General method to bulk link GraphQL objects by id
+        requests will be send in batch to avoid Payload Too Large exception
         :param from_ids: list of politylink ids
         :param to_ids: list of politylink ids
-        :return: json data
+        :return: json data of the last request
         """
 
+        ret = None
         op = Operation(Mutation)
         for from_id, to_id in zip(from_ids, to_ids):
             op = self.build_link_operation(from_id, to_id, op)
-        return self.exec(op)
+            if len(op) >= MAX_BATCH_SIZE:
+                ret = self.exec(op)
+                op = Operation(Mutation)
+        if len(op):
+            ret = self.exec(op)
+        return ret
 
     def get_all_bills(self):
         """
